@@ -119,7 +119,7 @@ def print_results(results):
                     package_issue.affected_location.vendor,
                     package_issue.affected_location.package,
                 )
-            if package_type and package_type != "*":
+            if package_type and package_type not in ("*", "o", "h"):
                 full_pkg = package_type + ":" + full_pkg
             table.append(
                 [
